Validasi class

Constructors

Validasi()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

any<T>([List<Rule<T>>? rules]) → ValidasiEngine<T, T>
list<T>([List<Rule<List<T>>>? rules]) → ValidasiEngine<List<T>, List<T>>
map<T>([List<Rule<Map<String, T>>>? rules]) → ValidasiEngine<Map<String, T>, Map<String, T>>
number<T extends num>([List<Rule<T>>? rules]) → ValidasiEngine<T, T>
string([List<Rule<String>>? rules]) → ValidasiEngine<String, String>