ValidasiField<T, V> class
abstract
A FieldDescriptor that can validate its own values.
- Inheritance
-
- Object
- FieldDescriptor<
T, V> - ValidasiField
- Implementers
Constructors
- ValidasiField()
-
const
Properties
Methods
-
extract(
T owner) → V? -
Extract the field value from a concrete model instance.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
V? value) → ValidasiResult< V> -
Validate
valueusing the rules defined for this field. -
validateAsync(
V? value) → Future< ValidasiResult< V> > -
Async counterpart of validate. By default it delegates to validate;
generated classes override this to support async rules (e.g.
@AsyncInline).
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited