ValidasiSchema<T> class
abstract
Allocates a typed model T from a ValidasiFieldReader.
Generated schemas implement this class and expose it as a schema constant
on the generated field class, e.g. UserFields.schema.
Constructors
- ValidasiSchema()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
allocate(
ValidasiFieldReader< T> reader) → T -
Builds a
Tinstance by reading field values fromreader. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited